@@ -3,8 +3,5 @@ Spezifiziert die Energierichtung einer Markt- und/oder Messlokation
 """
 from enum import Enum
 
-_energierichtung = {
-    "AUSSP": "AUSSP",  # Ausspeisung
-    "EINSP": "EINSP"  # Einspeisung
-}
+_energierichtung = {"AUSSP": "AUSSP", "EINSP": "EINSP"}  # Ausspeisung  # Einspeisung
 Energierichtung = Enum("Energierichtung", _energierichtung)
