@@ -7,6 +7,6 @@ from enum import Enum
 _rollenrodetyp = {
     "BDEW": "BDEW",  # Bundesverband der Energie- u. Wasserwirtschaft
     "DVG": "DVG",  # Deutscher Verein des Gas- und Wasserfaches
-    "GLN": "GLN"  # Global Location Number
+    "GLN": "GLN",  # Global Location Number
 }
 Rollencodetyp = Enum("Rollencodetyp", _rollenrodetyp)
