@@ -8,6 +8,6 @@ _verbrauchsart = {
     "KLW": "KLW",  # Kraft/Licht/Wärme
     "KLWS": "KLWS",  # Kraft/Licht/Wärme/Speicherheizung
     "W": "W",  # Wärme
-    "WS": "WS"  # Wärme/Speicherheizung
+    "WS": "WS",  # Wärme/Speicherheizung
 }
 Verbrauchsart = Enum("Verbrauchsart", _verbrauchsart)
